@@ -1,4 +1,5 @@
 from flask.json import JSONEncoder
+from datetime import datetime
 from bson import ObjectId, Timestamp
 from .uorm.models.base_model import BaseModel
 from .uorm.db import ObjectsCursor
@@ -15,6 +16,8 @@ def default(o):  # pylint: disable=method-hidden
         return list(o)
     if isinstance(o, BaseModel):
         return o.to_dict()
+    if isinstance(o, datetime):
+        return o.isoformat()
     raise TypeError(f"{repr(o)} is not JSON serializable")
 
 
